function [c] = CostKurtC_CPM(Y, f)

% [c] = CostKurtC_CPM(Y, f)
%
% Estimation of the kurtosis based contrast (complex valued signals)
% CostKurtC_CPM estimates the value of the contrast -Cum4{r}/E{|r|^2}^2
% where r = f'*Y;
%
% Inputs:
% -------
% Y = (No*D x Nsample) block-toeplitz matrix in which delayed version of
%   the observations are stacked (No: number of observations, D: lenght of
%   the separating filter)
% f = (1 x No*D) row vector containing the coefficients of the separating
%   filter (No: number of observations, D: lenght of the separating filter)
%
% Output: 
% -------
% c = value of the contrast
%
% -------
% Author: Marc Castella
% Created: 05/05/2010 (from CostKurtC)
% Last modified: 07/05/2010
% Contact: marc.castella@int-evry.fr

% Autres rq:
%% [c] = mk_cost (Y, f)
%%
%% Calcul du cout en un point pour
%% l'algorithme Maximisation de (Kurtosis)^2 (Methode de Simon)
%%
%% Y = matrice d'entree (q*Nx(T+1)
%% f = filtre non causal (q*Nx1)
%%
%% c = cout

%% Site   : Universite de Marne la Vallee
%% Auteur : Houcke <mazet@univ-mlv.fr>
%% Date   : 05/09/01

  %% Recuperation des dimensions

  qN = size(Y, 1);
  T = size(Y, 2);

  %% Calcul du cout

  fY = f'*Y;
  fYYf = fY.*conj(fY);
  
  D1 = sum(fYYf.*fYYf)/T;
  D2 = sum(fYYf)/T;
  D3 = sum(fY.*fY)/T;
  
  c = -((D1-D3*D3')/(D2^2)-2);
  
