
function [df, dfb,c] = DevKurtC_CPM(Y,f)

% [df,dfb,c] = DevKurtC_CPM(Y,f)
%
% Estimation of the kurtosis based contrast and its derivative (complex 
% valued signals)
% CostKurtC_CPM estimates the value of the contrast -Cum4{r}/E{|r|^2}^2
% where r = f'*Y; and the complex derivative of the contrast with respect
% to f
%
% Inputs:
% -------
% Y = (No*D x Nsample) block-toeplitz matrix in which delayed version of
%   the observations are stacked (No: number of observations, D: lenght of
%   the separating filter)
% f = (1 x No*D) row vector containing the coefficients of the separating
%   filter (No: number of observations, D: lenght of the separating filter)
%
% Outputs: 
% -------
% df = complex derivative with respect to f
% dfb = complex derivative with respect to conj(f)
% c = value of the contrast
% 
% -------
% Author: Marc Castella
% Created: 05/05/2010 (from DevKurtC)
% Last modified: 07/05/2010
% Contact: marc.castella@int-evry.fr

% Autres rq:
%% [df, dfb] = simon_dev (Y, f)
%%
%% Calcul des derives partielles du critere
%% de Maximisation de (Kurtosis)^2
%%
%% Y = matrice d'entree (q*Nx(T+1)
%% f = filtre non causal (q*Nx1)
%%
%% df = derivee partielle par rapport a f
%% dfb = derivee partielle par rapport a conj(f)

%% Site   : Universite de Marne la Vallee
%% Auteur : Houcke <houcke@univ-mlv.fr>
%% Date   : 05/09/01

%% Recuperation des dimensions

  qN = size(Y, 1);
  T = size(Y, 2);

  fY = f'*Y;
  fYYf = fY.*conj(fY);

  %% Calcul des trois termes

  D1 = sum(fYYf.*fYYf)/T;
  D2 = sum(fYYf)/T;
  D3 = sum(fY.*fY)/T;

  J_MK=(D1-D3*D3')/(D2^2)-2;
  c = -J_MK; %c = J_MK^2;
  %% Calcul de leur derivees

  dD1 = 2*Y*(conj(fY).*fYYf).'/T;
  dD2 = Y*conj(fY).'/T;
  dD3 = 2*Y*fY.'/T;

  %% Calcul de la derivee partielle df_barre

  %dfb =2*J_MK* ((dD1-dD3*D3')*D2-2*dD2*(D1-D3*D3'))/(D2^3);
  dfb = -( (dD1-dD3*D3')*D2-2*dD2*(D1-D3*D3') )/(D2^3);
  
  
  %% Calcul de la derivee partielle df

  %%  df = ((conj(dD1)-D3*conj(dD3))*D2-2*conj(dD2)*(D1-abs(D3)^2))/(D2^3);
  df = conj(dfb);
  
