function [dc_df,c] = DevKurtR(Y,f);

% [dc_df,c] = DevKurtR(Y,f)
%
% Estimation of the kurtosis based contrast and its derivative (real
% valued signals)
% CostKurtR estimates the value of the contrast (Cum4{r})^2/E{r^2}^2
% where r = f'*Y; and the derivative of the contrast with respect to f
%
% Inputs:
% -------
% Y = (No*D x Nsample) block-toeplitz matrix in which delayed version of
%   the observations are stacked (No: number of observations, D: lenght of
%   the separating filter)
% f = (1 x No*D) row vector containing the coefficients of the separating
%   filter (No: number of observations, D: lenght of the separating filter)
%
% Outputs: 
% -------
% dc_df = derivative with respect to f
% c = value of the contrast
% 
% -------
% Author: Marc Castella
% Created: ??
% Last modified: 04/07/2006
% Contact: marc.castella@int-evry.fr

%% Recuperation des dimensions
T = size(Y,2);

r = f'*Y;
r2 = r.^2;

% termes intermediaires
%D1 = 1/T*sum(r.^4);
D1 = r2*r2.'/T;
D2 = sum(r2)/T;

sqrtc = D1/D2^2 - 3;
c = (sqrtc)^2;

% Calcul de leurs derivees
%dD1 = 1/T*Y*(4*r.^3).';
%dD1 = 1/T*Y*(4*r2.*r).';
dD1 = 4/T*Y*(r2.*r).';
dD2 = 1/T*Y*(2*r).';

% Calcul de la derivee de c
dc_df = 2*(sqrtc)*(D2*dD1-2*D1*dD2)/D2^3;

