
function [mu] = OptStepC_CPM(Y, R, f, g)

% [mu] = OptStepC_CPM(X,R,f,g)
%
% Computation of the optimal gradient step size for the gradient descent
% algorithm in GradientKurtC_CPM.
%
% Inputs:
% -------
% X = (D*Nx x Nsample): observations and delayed observations (used as an 
%   input of the filter f to get the separated source f*Y)
%   (D: length of the separator, Nx: number of observations)
% R = 1/length(X)*X*X';
% f = (1 x D*Nx) vector: separating filter coefficients 
% g = conjugate derivative of the contrast wrt the filter coefficients. The
%   contrast is given by the function CostKurtC.
%
% Outputs: 
% -------
% mu = optimal step
% 
% -------
% Author: Marc Castella
% Created: 05/05/2010
% Last modified: 05/05/2010
% Contact: marc.castella@it-sudparis.eu

% [mu] = simon_mu (Y, R, f, dfb)
%
% Calcul du mu optimal en un point pour
% l'algorithme de MK
%
% Y = matrice d'entree (q*Nx(T+1)
% R = matrice  Y*Y' (q*Nxq*N)
% f = filtre non causal (q*Nx1)
% dfb = derivee partielle par rapport a conj(f)
%
% mu = mu optimal

% Site   : Universite de Marne la Vallee
% Auteur : S Houcke <houcke@univ-mlv.fr>
% Date   : 17/09/01

%error('Pas encore ready');

%% Recuperation des dimensions

qN = size(Y, 1);
T = size(Y, 2) - 1;

r = f'*Y;
e = g'*Y;
r2 = abs(r).^2;
re_ = r.*conj(e);
e2 = abs(e).^2;

D1 = zeros(1,5);
D1(1) = sum(e2.*e2);
D1(2) = - 4*sum( e2.*real(re_) ); % signe - car calculs faits avec f<-f+mu*g et f<-f-mu*g dans pgme
D1(3) = 2*sum( real(r.^2.*conj(e).^2) ) + 4*sum( abs(r2.*e2) );
D1(4) = - 4*sum( r2.*real(re_) ); % signe - car calculs faits avec f<-f+mu*g et f<-f-mu*g dans pgme
D1(5) = sum(r2.*r2);
D1 = D1/T;

D2 = zeros(1,3);
D2(1) = sum(e2);
D2(2) = - 2*sum(real(re_)); % signe - car calculs faits avec f<-f+mu*g et f<-f-mu*g dans pgme
D2(3) = sum(r2);
D2 = D2/T;

D3 = zeros(1,3);
D3(1) = sum(e.^2);
D3(2) = - 2*sum(r.*e); % signe - car calculs faits avec f<-f+mu*g et f<-f-mu*g dans pgme
D3(3) = sum(r.^2);
D3 = D3/T;


tmp1 = D1-conv(D3,conj(D3));
tmp2 = conv(D2,polyder(tmp1)) - 2*conv(tmp1,polyder(D2));
Poly_mu = conv(D2,tmp2);
mu = real(roots(Poly_mu));

for k=1:length(mu)
    f_mu = f - mu(k)*g;
    f_mu = f_mu/sqrt(f_mu'*R*f_mu);
    cout(k) = CostKurtC_CPM(Y, f_mu);
end;

%% Choix de mu optimal

[cou_max, mu_max] = max(cout);

mu = mu(mu_max);

% 
% 
% 
% dfb = g; % pour verif
% 
% fY = (f'*Y).';
% dfY = (dfb'*Y).';
% fYYf = fY.*conj(fY);
% dfYYf = dfY.*conj(fY);
% dfYYdf = dfY.*conj(dfY);
% 
% %% Calcul des trois polynomes en mu
% 
% pD1 = zeros(1,5);
% pD1(1) = sum(dfYYdf.*dfYYdf);
% pD1(2) = -sum(dfYYdf.*dfYYf)-sum(dfYYdf.*conj(dfYYf))-sum(dfYYf.*dfYYdf)-sum(conj(dfYYf).*dfYYdf);
% pD1(3) = sum(dfYYdf.*fYYf)+sum(dfYYf.*dfYYf)+sum(dfYYf.*conj(dfYYf))+sum(conj(dfYYf).*dfYYf)+sum(conj(dfYYf).*conj(dfYYf))+sum(fYYf.*dfYYdf);
% pD1(4) =  -sum(dfYYf.*fYYf)-sum(conj(dfYYf).*fYYf)-sum(fYYf.*dfYYf)-sum(fYYf.*conj(dfYYf));
% pD1(5) = sum(fYYf.*fYYf);
% pD1 = pD1/T;
% 
% pD2 = zeros(1,3);
% pD2(1) = sum(dfYYdf);
% pD2(2) = -sum(dfYYf)-sum(conj(dfYYf));
% pD2(3) = sum(fYYf);
% pD2 = pD2/T;
% 
% pD3 = zeros(1,3);
% pD3(1) = sum(dfY.*dfY);
% pD3(2) = -sum(dfY.*fY)-sum(fY.*dfY);
% pD3(3) = sum(fY.*fY);
% pD3 = pD3/T;
% 
% P = pD1-conv(pD3,conj(pD3));
% Q = conv(pD2, pD2);
% P_dev=conv(polyder(P),Q)-conv(P,polyder(Q));
% Poly_mu=conv(P,P_dev);
% mu = real(roots(Poly_mu));
% 
% 
% %% Calcul des couts
% 
% for k=1:length(mu)
%     f_mu = f - mu(k)*dfb;
%     f_mu = f_mu/sqrt(f_mu'*R*f_mu);
%     cout(k) = CostKurtC(Y, f_mu);
% end;
% 
% %% Choix de mu optimal
% 
% [cou_max, mu_max] = max(cout);
% 
% mu = mu(mu_max);
