function [mu] = OptStepR(Y,f,g);

% [mu] = OptStepR(X,f,g)
%
% Computation of the optimal gradient step size for the gradient descent
% algorithm in GradientKurtR.
%
% Inputs:
% -------
% X = (D*Nx x Nsample): observations and delayed observations (used as an 
%   input of the filter f to get the separated source f*Y)
%   (D: length of the separator, Nx: number of observations)
% f = (1 x D*Nx) vector: separating filter coefficients 
% g = derivative of the contrast wrt the filter coefficients. The contrast
%   is given by the function CostKurtR.
%
% Outputs: 
% -------
% mu = optimal step
% 
% -------
% Author: Marc Castella
% Created: ??
% Last modified: 19/06/2009
% Contact: marc.castella@it-sudparis.eu

% Recuperation des dimensions
T = size(Y,2);

r = f'*Y;
dr = g'*Y;

% Calcul des coefficient des polynomes en mu
dr2 = dr.^2; r2 = r.^2;
P2 = [1/T*sum(dr2) 2/T*sum(r.*dr) 1/T*sum(r2)];
Q2 = polyder(P2);
%P1 = [1/T*sum(dr.^4) 4/T*sum(r.*dr.^3) 6/T*sum(r2.*dr2) ...
%        4/T*sum(r.^3.*dr) 1/T*sum(r.^4) ];
P1 = [(dr2*dr2.')/T 4/T*sum(r.*dr2.*dr) 6/T*sum(r2.*dr2) ...
        4/T*sum(r2.*r.*dr) (r2*r2.')/T ];
Q1 = polyder(P1);

A = conv(P2,Q1) - 2*conv(P1,Q2);

% Les mu optimaux candidats
mu = roots(A);
if 1-isreal(mu),
    %disp('ATTENTION: un mu candidat non reel');
    ind_garder = find(imag(mu)==0);
    mu = mu(ind_garder);
    %disp('OK, mu non reels supprimes!');
end;


% Calcul des couts

for k=1:length(mu)
    f_mu = f+mu(k)*g;
    cout(k) = CostKurtR(Y,f_mu);
end;

% Choix de mu optimal
[cou_max, mu_max] = max(cout);
mu = mu(mu_max);

% if isreal(mu)==0,
%     disp('AAAAAAAAAAAAAAAAARGH!');
%     disp('HORRRRRRRRRRRRRRRRRRRRRRRRRREURRRRRRRRRRRRRRRRRRRRRRRR');
%     disp('Le mu optimal n est pas reel');
%     disp('ESPECE DE -:#');
% end;
