%% [mu] = simon_mu (Y, R, f, dfb)
%%
%% Calcul du mu optimal en un point pour
%% l'algorithme de MK
%%
%% Y = matrice d'entree (q*Nx(T+1)
%% R = matrice  Y*Y' (q*Nxq*N)
%% f = filtre non causal (q*Nx1)
%% dfb = derivee partielle par rapport a conj(f)
%%
%% mu = mu optimal

%% Site   : Universite de Marne la Vallee
%% Auteur : S Houcke <houcke@univ-mlv.fr>
%% Date   : 17/09/01

function [mu] = simon_mu (Y, R, f, dfb)

%% Recuperation des dimensions

qN = size(Y, 1);
T = size(Y, 2) - 1;

fY = (f'*Y).';
dfY = (dfb'*Y).';
fYYf = fY.*conj(fY);
dfYYf = dfY.*conj(fY);
dfYYdf = dfY.*conj(dfY);

%% Calcul des trois polynomes en mu

pD1 = zeros(1,5);
pD1(1) = sum(dfYYdf.*dfYYdf);
pD1(2) = -sum(dfYYdf.*dfYYf)-sum(dfYYdf.*conj(dfYYf))-sum(dfYYf.*dfYYdf)-sum(conj(dfYYf).*dfYYdf);
pD1(3) = sum(dfYYdf.*fYYf)+sum(dfYYf.*dfYYf)+sum(dfYYf.*conj(dfYYf))+sum(conj(dfYYf).*dfYYf)+sum(conj(dfYYf).*conj(dfYYf))+sum(fYYf.*dfYYdf);
pD1(4) =  -sum(dfYYf.*fYYf)-sum(conj(dfYYf).*fYYf)-sum(fYYf.*dfYYf)-sum(fYYf.*conj(dfYYf));
pD1(5) = sum(fYYf.*fYYf);
pD1 = pD1/T;

pD2 = zeros(1,3);
pD2(1) = sum(dfYYdf);
pD2(2) = -sum(dfYYf)-sum(conj(dfYYf));
pD2(3) = sum(fYYf);
pD2 = pD2/T;

pD3 = zeros(1,3);
pD3(1) = sum(dfY.*dfY);
pD3(2) = -sum(dfY.*fY)-sum(fY.*dfY);
pD3(3) = sum(fY.*fY);
pD3 = pD3/T;

P = pD1-conv(pD3,conj(pD3));
Q = conv(pD2, pD2);
P_dev=conv(polyder(P),Q)-conv(P,polyder(Q));
Poly_mu=conv(P,P_dev);
mu = real(roots(Poly_mu));

%% Calcul des couts

for k=1:length(mu)
    f_mu = f - mu(k)*dfb;
    f_mu = f_mu/sqrt(f_mu'*R*f_mu);
    cout(k) = CostKurtC(Y, f_mu);
end;

%% Choix de mu optimal

[cou_max, mu_max] = max(cout);

mu = mu(mu_max);

