function w = reswCw(C,R,dimReduc,rk);

% w = reswCw(C,R,dimReduc,rk);
%
% Optimization of a reference-based quadratic contrast function (under a
%   quadratic constraint)
% reswCw performs the optimization of the quadratic contrast described in
% [1] (see eq. (34))
%
% Inputs:
% -------
% C = cumulant matrix (given by the program makeRC.m)
% R = covariance matrix (given by the program makeRC.m)
% rk = rank of the matrix R (if known, otherwise assumed value) for the 
%   first step of the separating procedure (no previous deflation step). 
%   This corresponds to the value r_0 in the global procedure described 
%   in [1].
% dimReduc = value of the rank deficiency due to previous deflation
%   procedures. dimReduc = r_0 - r_i at the i-th source extraction (see the
%   description of the global separation procedure in [1]).
% 
% Output: 
% -------
% w = (1 x Nx.D) row vector containing the Nx.D coefficients of the
%   row separating filter where Nx is the number of observation signals and
%   D the length of the separating filter
%
% -------
% Author: Marc Castella
% Created: 11/2003
% Last modified: 03/07/2006
% Contact: marc.castella@int-evry.fr
%
% Ref:
% [1] Quadratic Higher-Order Criteria for Iterative Blind Separation of a 
% MIMO Convolutive Mixture of Sources / M. Castella, S. Rhioui, E. Moreau 
% and J.-C. Pesquet, IEEE Trans. on Signal Processing (accepted, to appear)

[U,S,V] = svd(R);
rg = rk-dimReduc;

%if rank(R)~=size(R,1), disp('Warning: R non de rang plein'); end;
%rg = size(R,1)-dimReduc;
if rank(R)<rg, disp('Warning: rank of R < assumed rank rk-dimReduc'); %k=diag(S).', 
    rg = rank(R); 
end;

%k=diag(S);
    P = diag(sqrt(diag(S(1:rg,1:rg))))*V(:,1:rg)';
    Q = V(:,1:rg)*diag(1./sqrt(diag(S(1:rg,1:rg)))); %maintenant P'P=R et QP = Id
[U,S,V] = svd(Q'*C*Q); 
w = Q*U(:,1); w = w';
