function y = MIMOfilt(H,x);

% [y] = MIMOfilt(H,x);
%
% MIMO digital filter
% MIMOfilt computes the output of the FIR-MIMO filter H driven by the
% multi-dimensionnal signal x
%
% Inputs:
% -------
% x = (Ni x Ns) matrix with Ns samples of the Ni input signals
% H = (No x Ni x L) array containing the impulse response of the
%   MIMO-filter (which has No outputs, Ni inputs, and length L)
%   H_{ij}(k) corresponds to H(i,j,k)
% Output: 
% -------
% y = (No x Ns-L+1) matrix with the samples of the No output signals
%
% See also: MIMOfiltconv
% -------
% Author: Marc Castella
% Created: 12/06/2002
% Last modified: 05/07/2006
% Contact: marc.castella@int-evry.fr

% Autres rq:
%   y(n) = H(0)x(n) + H(1)x(n-1) + ...
%   H_{ij}(k) correspond a H(i,j,k)

N = size(H,1);
Ne= size(x,2); % nombre d'echantillons
L = size(H,3); % H est FIR de taille N

y = zeros(N,Ne-L+1);
for i = 1:L,
    y = y + H(:,:,i)*x(:,L-i+1:end-i+1);
end;

% % version au 11/02/2002
% Ne= length(x); % nombre d'echantillons
% L = size(H,3); % H est FIR de taille N
% 
% y = zeros(2,Ne-L+1);
% for i = 1:L,
%     y = y + H(:,:,i)*x(:,L-i+1:end-i+1);
% end;
